@@ -1,3 +1,5 @@
+//! Low-level representations for Cloud Native Buildpack data types.
+
 pub mod bom;
 pub mod build;
 pub mod build_plan;
@@ -5,5 +7,5 @@ pub mod buildpack;
 pub mod buildpack_plan;
 pub mod defaults;
 pub mod launch;
-pub mod layer;
+pub mod layer_content_metadata;
 pub mod store;
